@@ -1,3 +1,38 @@
+#
+#  BSD LICENSE
+#
+#  Copyright (c) Crane Chu <cranechu@gmail.com>
+#  All rights reserved.
+#
+#  Redistribution and use in source and binary forms, with or without
+#  modification, are permitted provided that the following conditions
+#  are met:
+#
+#    * Redistributions of source code must retain the above copyright
+#      notice, this list of conditions and the following disclaimer.
+#    * Redistributions in binary form must reproduce the above copyright
+#      notice, this list of conditions and the following disclaimer in
+#      the documentation and/or other materials provided with the
+#      distribution.
+#    * Neither the name of Intel Corporation nor the names of its
+#      contributors may be used to endorse or promote products derived
+#      from this software without specific prior written permission.
+#
+#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+#  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+#  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+#  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+#  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+#  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+#  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+#  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+#  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+# -*- coding: utf-8 -*-
+
+
 import time
 import pytest
 import logging
@@ -8,8 +43,8 @@ import nvme as d
 # intuitive, spec, qpair, vscode, debug, cmdlog, assert
 def test_hello_world(nvme0, nvme0n1, qpair):
     # prepare data buffer and IO queue
-    read_buf = d.Buffer(512)
-    write_buf = d.Buffer(512)
+    read_buf = d.Buffer()
+    write_buf = d.Buffer()
     write_buf[10:21] = b'hello world'
 
     # send write and read command
@@ -37,10 +72,10 @@ def test_sanitize(nvme0: d.Controller, buf):
     if nvme0.id_data(331, 328) == 0:
         pytest.skip("sanitize operation is not supported")
 
-    import PySimpleGUI as sg
+    #import PySimpleGUI as sg
 
     logging.info("supported sanitize operation: %d" % nvme0.id_data(331, 328))
-    sg.OneLineProgressMeter('sanitize progress', 0, 100, 'progress', orientation='h')
+    #sg.OneLineProgressMeter('sanitize progress', 0, 100, 'progress', orientation='h')
     nvme0n1 = d.Namespace(nvme0, 1, 128*1000*1000//4)
     nvme0.sanitize().waitdone()  # sanitize clears namespace
 
@@ -50,7 +85,7 @@ def test_sanitize(nvme0: d.Controller, buf):
         time.sleep(1)
         nvme0.getlogpage(0x81, buf, 20).waitdone()
         progress = buf.data(1, 0)*100//0xffff
-        sg.OneLineProgressMeter('sanitize progress', progress, 100, 'progress', orientation='h')
+        #sg.OneLineProgressMeter('sanitize progress', progress, 100, 'progress', orientation='h')
         logging.info("%d%%" % progress)
 
     nvme0n1.close()
